@@ -13,6 +13,4 @@ setClass("glub",
          contains = "swift"
          )
 
-## Following modified from the Matrix package:
-setClassUnion("index", members =  c("numeric", "logical", "character"))
 
